@@ -11,7 +11,8 @@ from OpenSSL import crypto
 
 def get_apns_certificate(cert_path, cert_pw):
     p12 = crypto.load_pkcs12(open(cert_path, 'rb').read(), cert_pw)
-    return p12
+    pem = crypto.dump_privatekey(crypto.FILETYPE_PEM, p12.get_privatekey())
+    return pem
 
 
 class NotificationStack(Stack): 
@@ -23,8 +24,7 @@ class NotificationStack(Stack):
 
         pinpoint_app = pinpoint.CfnApp(self, pinpoint_app_name, name=pinpoint_app_name)
 
-        apns_certificate = get_apns_certificate(apns_certificate_path, apns_certificate_pw)
-        print(apns_certificate.get_certificate())
+        apns_certificate = get_apns_certificate(apns_certificate_path, apns_certificate_pw) 
 
         cfn_aPNSSandbox_channel = pinpoint.CfnAPNSSandboxChannel(self, "{}-apns-sandbox".format(pinpoint_app_name),
             application_id=pinpoint_app.ref,
@@ -34,7 +34,7 @@ class NotificationStack(Stack):
             # certificate=apns_certificate.get_certificate(),
             default_authentication_method="certificate",
             enabled=True,
-            private_key=apns_certificate.get_privatekey(),
+            private_key=apns_certificate,
             # team_id="teamId",
             # token_key="tokenKey",
             # token_key_id="tokenKeyId"
